@@ -2,7 +2,9 @@
 
 use crate::implementation::two_bit_vec_sequence::{TwoBitVectorGenome, TwoBitVectorSubGenome};
 use crate::interface::sequence::GenomeSequence;
-use crate::interface::sequence_store::{HandleWithLength, HandleWithSubsequence, SequenceStore};
+use crate::interface::sequence_store::{
+    HandleWithLength, HandleWithSubsequence, InverseMappingSequenceStore, SequenceStore,
+};
 use traitsequence::interface::Sequence;
 
 /// A bitvector based sequence store.
@@ -54,6 +56,15 @@ impl SequenceStore for TwoBitVectorSequenceStore {
     }
 }
 
+impl InverseMappingSequenceStore for TwoBitVectorSequenceStore {
+    fn map_sequence_ref_to_handle(&self, sequence_ref: &Self::SequenceRef) -> Self::Handle {
+        Self::Handle {
+            offset: sequence_ref.bits.offset_from(&self.sequence.bits[..]) as usize / 2,
+            len: sequence_ref.len(),
+        }
+    }
+}
+
 impl HandleWithLength for TwoBitVectorSequenceStoreHandle {
     fn len(&self) -> usize {
         self.len
